## sjmm_util

A collection of misc functions developed to make certain data analysis, plotting, and fitting tasks easier.

## modules:

- `line_utils`: codes for analyzing millimeter lines, converting frequencies, etc.
- `scuba2_utils`: codes for working with reduced, matched-filtered SCUBA-2 data. Credit to Li-Yen Hsu for the original versions, which I've adapted.
- `config`: my (evolving) personal config / matplotlib style sheet, etc.
- `general_utils`: everything else!

These are mainly for my own use, but if you find them useful, feel free to leave a comment on the Github page.

Author: S. McKay, 2025
